@@ -12,6 +12,11 @@ extern crate serde_derive;
 #[macro_use]
 extern crate bart_derive;
 
+#[macro_use]
+extern crate thiserror;
+
+extern crate rand;
+extern crate rand_regex;
 extern crate serde;
 extern crate serde_json;
 
@@ -45,7 +50,7 @@ pub use conversions::{render_dfa_dot_string, render_nt_dot_string, render_par_st
 pub mod generators;
 pub use generators::{
     check_and_transform_grammar, generate_lexer_source, generate_parser_source,
-    generate_user_trait_source, try_format, GrammarConfig, ScannerConfig,
+    generate_user_trait_source, try_format, GrammarConfig, LanguageGenerator, ScannerConfig,
 };
 
 pub mod parser;
